==> aiccu_2005.01.31.tar.gz: aiccu/common/aiccu_kame.c <==
/**********************************************************
 SixXS - Automatic IPv6 Connectivity Configuration Utility
***********************************************************
 Copyright 2003-2005 SixXS - http://www.sixxs.net
***********************************************************
 common/aiccu_kame.c - NetBSD + FreeBSD 5.x+
***********************************************************
 $Author: jeroen $
 $Id: aiccu_kame.c,v 1.8 2005/01/31 20:32:50 jeroen Exp $
 $Date: 2005/01/31 20:32:50 $
**********************************************************/

#include "aiccu.h"

void aiccu_os_install()
{
}

void aiccu_os_setup(struct TIC_Tunnel *hTunnel)
{
	if (strcmp(hTunnel->sType, "ayiya") != 0)
	{
		aiccu_exec(
			"/sbin/ifconfig %s create",
			g_aiccu->ipv6_interface);

		aiccu_exec(
			"/sbin/ifconfig %s tunnel %s %s",
			g_aiccu->ipv6_interface,
			strcmp(hTunnel->sIPv4_Local, "heartbeat") == 0 ? "0.0.0.0" : hTunnel->sIPv4_Local,
			hTunnel->sIPv4_POP);
	}

	aiccu_exec(
		"ifconfig %s up",
		g_aiccu->ipv6_interface);

	if (strcmp(hTunnel->sType, "ayiya") == 0)
	{
		aiccu_exec(
			"ifconfig %s inet6 %s prefixlen 64 alias",
			g_aiccu->ipv6_interface,
			hTunnel->sIPv6_LinkLocal);
	}

	aiccu_exec(
		"ifconfig %s inet6 %s prefixlen 128 alias",
		g_aiccu->ipv6_interface,
		hTunnel->sIPv6_Local);

	aiccu_exec(
		"route add -inet6 %s -prefixlen 128 %s",
		hTunnel->sIPv6_POP,
		hTunnel->sIPv6_Local);

	aiccu_exec(
		"route add -inet6 %s %s",
		"default",
		hTunnel->sIPv6_POP);
}

void aiccu_os_reconfig(struct TIC_Tunnel *hTunnel)
{
	if (strcmp(hTunnel->sType, "ayiya") != 0)
	{
		aiccu_exec(
			"/sbin/ifconfig %s tunnel %s %s",
			g_aiccu->ipv6_interface,
			hTunnel->sIPv4_Local,
			hTunnel->sIPv4_POP);
	}
}

void aiccu_os_delete(struct TIC_Tunnel *hTunnel)
{
	hTunnel = hTunnel;
	aiccu_exec(
		"ifconfig %s down",
		g_aiccu->ipv6_interface);

	if (strcmp(hTunnel->sType, "ayiya") != 0)
	{
		aiccu_exec(
			"ifconfig %s deletetunnel",
			g_aiccu->ipv6_interface);
	}
}

==> aiccu_2006.07.25.tar.gz: aiccu/common/aiccu_kame.c <==
/**********************************************************
 SixXS - Automatic IPv6 Connectivity Configuration Utility
***********************************************************
 Copyright 2003-2005 SixXS - http://www.sixxs.net
***********************************************************
 common/aiccu_kame.c - NetBSD + FreeBSD 5.x+
***********************************************************
 $Author: jeroen $
 $Id: aiccu_kame.c,v 1.12 2006-07-23 14:13:57 jeroen Exp $
 $Date: 2006-07-23 14:13:57 $
**********************************************************/

#include "aiccu.h"

bool aiccu_os_install(void)
{
	return true;
}

bool aiccu_os_setup(struct TIC_Tunnel *hTunnel)
{
	if (hTunnel->uses_tundev == 0)
	{
		aiccu_exec(
			"/sbin/ifconfig %s create",
			g_aiccu->ipv6_interface);

		aiccu_exec(
			"/sbin/ifconfig %s tunnel %s %s",
			g_aiccu->ipv6_interface,
			strcmp(hTunnel->sIPv4_Local, "heartbeat") == 0 ? "0.0.0.0" : hTunnel->sIPv4_Local,
			hTunnel->sIPv4_POP);
	}

	aiccu_exec(
		"ifconfig %s up",
		g_aiccu->ipv6_interface);

	if (hTunnel->uses_tundev == 1)
	{
		/* Configure a generated linklocal address */
		aiccu_exec(
			"ifconfig %s inet6 %s prefixlen 64 alias",
			g_aiccu->ipv6_interface,
			hTunnel->sIPv6_LinkLocal);

		/* Local side of the tunnel */
		aiccu_exec(
			"ifconfig %s inet6 %s prefixlen 128 alias",
			g_aiccu->ipv6_interface,
			hTunnel->sIPv6_Local);

		/* Remote side of the tunnel */
		aiccu_exec(
			"route add -inet6 %s -prefixlen 128 %s",
			hTunnel->sIPv6_POP,
			hTunnel->sIPv6_Local);
	}
	else
	{
		/* PtP link, so we can use the PtP syntax */
		aiccu_exec(
			"ifconfig %s inet6 %s %s prefixlen 128 alias",
			g_aiccu->ipv6_interface,
			hTunnel->sIPv6_Local,
			hTunnel->sIPv6_POP);
	}

	if (g_aiccu->defaultroute)
	{
		aiccu_exec(
			"route add -inet6 %s %s",
			"default",
			hTunnel->sIPv6_POP);
	}

	return true;
}

void aiccu_os_reconfig(struct TIC_Tunnel *hTunnel)
{
	if (hTunnel->uses_tundev == 0)
	{
		aiccu_exec(
			"/sbin/ifconfig %s tunnel %s %s",
			g_aiccu->ipv6_interface,
			hTunnel->sIPv4_Local,
			hTunnel->sIPv4_POP);
	}
}

void aiccu_os_delete(struct TIC_Tunnel *hTunnel)
{
	hTunnel = hTunnel;
	aiccu_exec(
		"ifconfig %s down",
		g_aiccu->ipv6_interface);

	if (hTunnel->uses_tundev == 0)
	{
		aiccu_exec(
			"ifconfig %s deletetunnel",
			g_aiccu->ipv6_interface);
	}
}
